==> open-xchange-guard_2.8.0.orig.tar.bz2: open-xchange-guard-2.8.0/com.openexchange.guard.hkpclient/src/com/openexchange/guard/hkpclient/services/HKPKeySources.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.hkpclient.services;

import com.openexchange.guard.keymanagement.commons.trust.KeySource;

/**
 * {@link HKPKeySources} defines a set of default HKP key sources ({@link KeySource}).
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.6.0
 */
class HKPKeySources {

    /**
     * The {@link KeySource} for public available key servers (for example keys.gnupg.net)
     */
    final static KeySource PUBLIC_HKP_REMOTE_SERVER = new KeySource("HKP_PUBLIC_SERVER", 1);

    /**
     * The {@link KeySource} for trusted public, or private key servers
     */
    final static KeySource TRUSTED_HKP_REMOTE_SERVER = new KeySource("HKP_TRUSTED_SERVER", 5);

    /**
     * The {@link KeySource} for key servers discovered by a SRV DNS Record
     */
    final static KeySource SRV_HKP_REMOTE_SERVER = new KeySource("HKP_SRV_SERVER", 4);

    /**
     * The {@link KeySource} for cached keys
     */
    final static KeySource CACHE_HKP_KEYSOURCE = new KeySource("HKP_CACHE", 4);
}

==> open-xchange-guard_2.10.5.orig.tar.bz2: open-xchange-guard-2.10.5/com.openexchange.guard.hkpclient/src/com/openexchange/guard/hkpclient/services/HKPKeySources.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.hkpclient.services;

import com.openexchange.guard.configuration.GuardProperty;
import com.openexchange.guard.keymanagement.commons.trust.KeySource;
import com.openexchange.guard.keymanagement.commons.trust.KeySourceFactory;

/**
 * {@link HKPKeySources} defines a set of default HKP key sources ({@link KeySource}).
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.6.0
 */
public class HKPKeySources {

    /**
     * The {@link KeySource} for public available key servers (for example keys.gnupg.net)
     */
    static KeySource PUBLIC_HKP_REMOTE_SERVER;

    /**
     * The {@link KeySource} for trusted public, or private key servers
     */
    static KeySource TRUSTED_HKP_REMOTE_SERVER;

    /**
     * The {@link KeySource} for key servers discovered by a SRV DNS Record
     */
    static KeySource SRV_HKP_REMOTE_SERVER;

    /**
     * The {@link KeySource} for key servers discovered by a SRV DNS Record
     */
    static KeySource SRV_HKP_DNSSEC_REMOTE_SERVER;

    /**
     * Initializes all HKP key source values
     * @param keySourceFactory
     */
    public static void initialize(KeySourceFactory keySourceFactory) {
        PUBLIC_HKP_REMOTE_SERVER = keySourceFactory.create("HKP_PUBLIC_SERVER", GuardProperty.trustLevelHKPPublicServer);
        TRUSTED_HKP_REMOTE_SERVER = keySourceFactory.create("HKP_TRUSTED_SERVER", GuardProperty.trustLevelHKPTrustedServer);
        SRV_HKP_REMOTE_SERVER = keySourceFactory.create("HKP_SRV_SERVER", GuardProperty.trustLevelHKPSRVServer);
        SRV_HKP_DNSSEC_REMOTE_SERVER = keySourceFactory.create("HKP_SRV_DNSSEC_SERVER", GuardProperty.trustLevelHKPSRVDNSSECServer);
    }
}
